package Tsk::Stack;
use 5.012005;
use strict;
use warnings;
use Tsk;
require Exporter;
our @ISA = qw(Exporter);
our @EXPORT = @Tsk::EXPORT;

1;
